/**
 * JWT authentication module
 */
import { AbstractAuth, IAuthIdentity, IAccessDetails, GenericResult, IAuthData, IAuthOptions, IAuthIdentityOptions, IAuthGrantOptions, IAuthVerifyOptions } from "@skazska/abstract-service-model";
/**
 * JWT Auth constructor module
 */
export interface IJWTAuthOptions extends IAuthOptions {
}
export interface IJWTAuthData extends IAuthData {
    realms?: string[];
}
export interface IJWTAuthGrantOptions extends IAuthGrantOptions {
    realms?: string[];
}
export interface IJWTAuthVerifyOptions extends IAuthVerifyOptions {
    realm?: string;
}
export declare class JWTAuth extends AbstractAuth {
    /**
     * @param identityConstructor
     * @param options
     */
    constructor(identityConstructor: (subject: string, details: IAccessDetails, options?: IAuthIdentityOptions) => IAuthIdentity, options?: IJWTAuthOptions);
    /**
     * checks token and returns auth data
     * @param secret - secret to use
     * @param token - token
     * @param options
     */
    protected verify(secret: any, token: string, options?: IJWTAuthVerifyOptions): Promise<GenericResult<IJWTAuthData>>;
    /**
     * generates token
     * @param details - auth details
     * @param subject - subject
     * @param options
     */
    grant(details: any, subject: string, options?: IJWTAuthGrantOptions): Promise<GenericResult<string>>;
}
